@@ -89,7 +89,15 @@ TECH_CLASSES = [
     "DJ55xx",
     "OJProKx50",
     'LJP1XXX',
-    'DJD2600',
+    #'DJD2600', not used. Reassigned all these to ViperPlusTrim and ViperMinusTrim Class
+    "Stabler",
+    "ViperPlusVIP",
+    "ViperMinusVIP",
+    "ViperPlusTrim",
+    "ViperMinusTrim",
+    "Corbett",
+    "Python",
+    "OJ7000",
 ]
 
 TECH_CLASSES.sort()
@@ -132,6 +140,14 @@ TECH_CLASS_PDLS = {
     "DJ55xx"       : 'pcl3',
     "OJProKx50"    : 'pcl3',
     'LJP1XXX'      : 'zxs',
+    "Stabler"      : 'pcl3',
+    "ViperPlusVIP" : 'pcl3',
+    "ViperMinusVIP": 'pcl3',
+    "ViperPlusTrim" : 'lidil',
+    "ViperMinusTrim": 'lidil',
+    "Corbett"       : 'pcl3',
+    "Python"        : 'pcl3',
+    "OJ7000"        : 'pcl3',
 }
 
 PDL_TYPE_PCL = 0  # less preferred
@@ -177,6 +193,9 @@ TECH_SUBCLASSES = [
     "GrayscaleOnly", # DJ540
     "NoAutoTray", # PS Pro 8850
     "NoEvenDuplex", # PS C8100
+    "NoAutoDuplex",
+    "NoCDDVD",
+    "NoMaxDPI",
 ]
 
 TECH_SUBCLASSES.sort()
@@ -271,6 +290,7 @@ class ModelData:
             'r-type' : TYPE_INT,
             'scan-style' : TYPE_INT,
             'scan-type' : TYPE_INT,
+            #'scan-duplex' : TYPE_BOOL,
             'status-battery-check' : TYPE_INT,
             'status-dynamic-counters' : TYPE_INT,
             'status-type' : TYPE_INT,
