@@ -97,7 +97,7 @@ Printer::Printer
     // Allocate memory for my send buffer
     pSendBuffer = NULL;
 #ifdef APDK_BUFFER_SEND
-    pSendBuffer = pSS->AllocMem(iBuffSize);
+    pSendBuffer = pSS->AllocMem(iBuffSize+2);
     CNEWCHECK(pSendBuffer);
 #endif
 
@@ -590,7 +590,8 @@ DRIVER_ERROR Printer::Send
     residual = dwSendSize;
 
     if (bCheckForCancelButton &&
-        (ulBytesSentSinceCancelCheck >= CANCEL_BUTTON_CHECK_THRESHOLD) )
+        (ulBytesSentSinceCancelCheck >= CANCEL_BUTTON_CHECK_THRESHOLD) &&
+        (pSS->IOMode.bDevID))
     {
         ulBytesSentSinceCancelCheck = 0;
         char* tmpStr;
