@@ -52,38 +52,19 @@ class NoDevicesForm(NoDevicesForm_base):
 
     def setupPushButton_clicked(self):
         self.close()
-        su_sudo = None
-
-        if utils.which('kdesu'):
-            su_sudo = 'kdesu -- %s'
-
-        elif utils.which('gnomesu'):
-            su_sudo = 'gnomesu -c "%s"'
-
-        elif utils.which('gksu'):
-            su_sudo = 'gksu "%s"'
-
-        if su_sudo is None:
-            QMessageBox.critical(self,
-                                self.caption(),
-                                self.__tr("<b>Unable to find an appropriate su/sudo utility to run hp-setup.</b>"),
-                                QMessageBox.Ok,
-                                QMessageBox.NoButton,
-                                QMessageBox.NoButton)
 
+        if utils.which('hp-setup'):
+            cmd = 'hp-setup -u'
         else:
-            if utils.which('hp-setup'):
-                cmd = su_sudo % 'hp-setup -u'
-            else:
-                cmd = su_sudo % 'python ./setup.py -u'
+            cmd = 'python ./setup.py -u'
 
-            log.debug(cmd)
-            utils.run(cmd, log_output=True, password_func=None, timeout=1)
+        log.debug(cmd)
+        utils.run(cmd, log_output=True, password_func=None, timeout=1)
 
-            try:
-                self.parent().RescanDevices()
-            except Error:
-                QMessageBox.critical(self,
+        try:
+            self.parent().RescanDevices()
+        except Error:
+            QMessageBox.critical(self,
                                     self.caption(),
                                     self.__tr("<b>An error occurred.</b><p>Please re-start the Device Manager and try again."),
                                     QMessageBox.Ok,
